/*---------------------------------------------------------
 * Copyright (C) Microsoft Corporation. All rights reserved.
 *--------------------------------------------------------*/
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
let path = require('path');
let childProcess = require('child_process');
/*
 * Set the following compile time flag to true if the
 * debug adapter should run inside the extension host.
 * Please note: the test suite does no longer work in this mode.
 */
const EMBED_DEBUG_ADAPTER = true;
function activate(context) {
    context.subscriptions.push(vscode.commands.registerCommand('extension.mock-debug.getProgramName', config => {
        return vscode.window.showInputBox({
            placeHolder: "Please enter the name of a markdown file in the workspace folder",
            value: "readme.md"
        });
    }));
    // register a configuration provider for 'mock' debug type
    const provider = new MockConfigurationProvider();
    context.subscriptions.push(vscode.debug.registerDebugConfigurationProvider('mock', provider));
    context.subscriptions.push(provider);
}
exports.activate = activate;
function deactivate() {
    // nothing to do
}
exports.deactivate = deactivate;
class MockConfigurationProvider {
    /**
     * Massage a debug configuration just before a debug session is being launched,
     * e.g. add all missing attributes to the debug configuration.
     */
    resolveDebugConfiguration(folder, config, token) {
        // if launch.json is missing or empty
        if (!config.type && !config.request && !config.name) {
            const editor = vscode.window.activeTextEditor;
            if (editor && editor.document.languageId === 'DemonScript') {
                config.type = 'mock';
                config.name = 'Launch';
                config.request = 'launch';
                config.program = '${file}';
                config.debuggerPath = 'S:/!MOBILE/AI/DemonScript/ds.exe';
                config.debuggerPort = 4711;
            }
        }
        if (!config.program) {
            return vscode.window.showInformationMessage("Cannot find a program to debug").then(_ => {
                return undefined; // abort launch
            });
        }
        //config.program = `${folder.uri.fsPath}${path.sep}${config.program}`;
        //config.program = `${folder.uri.fsPath}${path.sep}${config.program}`;
        if (EMBED_DEBUG_ADAPTER && !config.debugServer) {
            // exec
            let command = config.debuggerPath + ' --debuggerClient vscode --debuggerPort ' + config.debuggerPort;
            let options = {};
            this._server = childProcess.exec(command, options, (error, stdout, stderr) => {
                console.log(error);
                console.log(stdout);
                console.log(stderr);
            });
            // make VS Code connect to debug server instead of launching debug adapter
            config.debugServer = config.debuggerPort;
        }
        return config;
    }
    dispose() {
        if (this._server)
            this._server.kill();
    }
}
//# sourceMappingURL=extension.js.map